@@ -12,7 +12,6 @@
 #include <openvas/system.h> /* for efree */
 
 
-#undef DEBUG
 #undef SHOW_RETRIES
 #undef SHOW_RTT_REMOVAL
 
@@ -28,10 +27,9 @@ struct pseudohdr {
 	struct tcphdr   tcpheader;
 };
 
-static int 
-in_cksum(p, n)
-	u_short        *p;
-	int             n;
+
+static int
+in_cksum (u_short *p, int n)
 {
 	register u_short answer;
 	register unsigned long sum = 0;
@@ -54,35 +52,31 @@ in_cksum(p, n)
 }
 
 
-
-unsigned long 
-maketime()
+unsigned long
+maketime ()
 {
 	struct timeval  tv;
 	unsigned long   ret;
 
 	gettimeofday(&tv, NULL);
 
-
-
 	ret = ((tv.tv_sec & 0x0000000F) << 28) | (((tv.tv_usec) & 0xFFFFFFF0) >> 4);
 
-
-	return htonl(ret);
+	return htonl (ret);
 }
 
 
-struct timeval 
-timeval(unsigned long val)
+struct timeval
+timeval (unsigned long val)
 {
 	struct timeval  ret;
 	unsigned int h, l;
 
-	val = ntohl(val);
+	val = ntohl (val);
 
 	h = ( val & 0xF0000000 ) >> 28;
 	l = ( val & 0x0FFFFFFF)  << 4;
-     
+
 	ret.tv_sec = h;
 	ret.tv_usec = l;
 	while ( ret.tv_usec >= 1000000 ) 
@@ -99,13 +93,8 @@ timeval(unsigned long val)
 }
 
 
-
-
-
-
-
-unsigned long 
-compute_rtt(unsigned long then)
+unsigned long
+compute_rtt (unsigned long then)
 {
 	unsigned long   now = maketime();
 	unsigned long   res;
@@ -126,8 +115,8 @@ compute_rtt(unsigned long then)
 }
 
 
-int 
-packetdead(unsigned long then, unsigned long rtt)
+int
+packetdead (unsigned long then, unsigned long rtt)
 {
 	unsigned long   now = maketime();
 
@@ -135,8 +124,6 @@ packetdead(unsigned long then, unsigned long rtt)
 	now = ntohl(now);
 	rtt = ntohl(rtt);
 
-
-
 	if ((now - then) >= 2 << 28 ) {
 		return 1;
 	} else {
@@ -145,57 +132,81 @@ packetdead(unsigned long then, unsigned long rtt)
 }
 
 
-int rawsocket(int family)
+/**
+ * @brief Opens and returns a raw socket.
+ */
+int
+rawsocket (int family)
 {
   int soc;
   int opt = 1;
   int offset = 8;
 
-  if(family == AF_INET)
-  {
-    soc = socket(AF_INET, SOCK_RAW, IPPROTO_RAW);
-    if (soc < 0) {
-     perror("socket ");
-     printf("error opeinig socket\n");
-     return -1;
+  if (family == AF_INET)
+    {
+      soc = socket (AF_INET, SOCK_RAW, IPPROTO_RAW);
+      if (soc < 0)
+        {
+          perror ("socket ");
+          printf ("error opeinig socket\n");
+          return -1;
+        }
+      if (setsockopt (soc, IPPROTO_IP, IP_HDRINCL, /*(char *) */&opt, sizeof (opt)) < 0)
+        {
+          perror ("setsockopt ");
+          printf ("error setting socket opt\n");
+          close (soc);
+          return -1;
+        }
     }
-    if (setsockopt(soc, IPPROTO_IP, IP_HDRINCL, (char *) &opt, sizeof(opt)) < 0) {
-      perror("setsockopt ");
-      printf("error setting socket opt\n");
-      close(soc);
-      return -1;
-    }
-  }
   else
-  {
-    soc = socket(AF_INET6, SOCK_RAW, IPPROTO_TCP);
-    if (soc < 0) {
-     perror("socket ");
-     printf("error opeinig socket\n");
-     return -1;
+    {
+      soc = socket (AF_INET6, SOCK_RAW, IPPROTO_TCP);
+      if (soc < 0)
+        {
+          perror ("socket ");
+          printf ("error opeinig socket\n");
+          return -1;
+        }
+      setsockopt (soc, IPPROTO_IPV6, IPV6_CHECKSUM, &offset, sizeof (offset));
     }
-    setsockopt(soc, IPPROTO_IPV6, IPV6_CHECKSUM, &offset, sizeof(offset));
-  }
 
   return soc;
 }
 
 
-int 
-openbpf(struct in_addr dst, struct in_addr * src, int magic)
+/**
+ * @brief Opens a packet filter, grabs packets from \ref dst to port \ref magic
+ *
+ * @param[out] src   in_addr of source.
+ * @param[in]  dst   Destination.
+ * @param[in]  magic Destination port on src to listen to.
+ *
+ * @return A bpf that listens to tcp packets coming from \ref dst to port
+ *         \ref magic.
+ */
+int
+openbpf (struct in_addr dst, struct in_addr * src, int magic)
 {
 	char           *iface;
 	char            filter[255];
 	int             bpf;
 
-	iface = routethrough(&dst, src);
-	snprintf(filter, sizeof(filter), "tcp and src host %s and dst port %d", inet_ntoa(dst), magic);
-	bpf = bpf_open_live(iface, filter);
+	iface = routethrough (&dst, src);
+#ifdef DEBUG
+        printf ("Source adress found via routethrough: %s\n", inet_ntoa (*src));
+#endif
+        snprintf (filter, sizeof (filter), "tcp and src host %s and dst port %d", inet_ntoa (dst), magic);
+#ifdef DEBUG
+        printf ("Open bpf on interface %s with filter: %s\n", iface, filter);
+#endif
+	bpf = bpf_open_live (iface, filter);
 	return bpf;
 }
 
-int 
-v6_openbpf(struct in6_addr *dst, struct in6_addr * src, int magic)
+
+int
+v6_openbpf (struct in6_addr *dst, struct in6_addr * src, int magic)
 {
   char *iface;
   char filter[255];
@@ -204,15 +215,16 @@ v6_openbpf(struct in6_addr *dst, struct in6_addr * src, int magic)
 
   iface = v6_routethrough(dst, src);
 
-  snprintf(filter, sizeof(filter), "tcp and src host %s and dst port %d",
-            inet_ntop(AF_INET6, dst, hostname, sizeof(hostname)), magic);
-  bpf = bpf_open_live(iface, filter);
-  if(bpf < 0)
+  snprintf (filter, sizeof(filter), "tcp and src host %s and dst port %d",
+            inet_ntop (AF_INET6, dst, hostname, sizeof (hostname)), magic);
+  bpf = bpf_open_live (iface, filter);
+  if (bpf < 0)
     printf("bpf_open_live returned error\n");
   return bpf;
 }
 /*----------------------------------------------------------------------------*/
 
+
 struct list {
 	unsigned short  dport;
 	unsigned long   when;
@@ -221,10 +233,16 @@ struct list {
 	struct list    *next;
 };
 
-struct list    *
-get_packet(struct list * l, unsigned short dport)
+
+/**
+ * @return First pointer to list in l with the given \ref dport , NULL if no
+ *         such list item could be found.
+ */
+struct list*
+get_packet (struct list * l, unsigned short dport)
 {
-	while (l != NULL) {
+	while (l != NULL)
+	{
 		if (l->dport == dport)
 			return l;
 		else
@@ -234,22 +252,26 @@ get_packet(struct list * l, unsigned short dport)
 }
 
 
-struct list    *
-add_packet(struct list * l, unsigned short dport, unsigned long ack)
+/**
+ * @brief If no packet with \ref dport is in list, prepends a "packet" to the
+ * @brief list \ref l.
+ */
+struct list*
+add_packet (struct list * l, unsigned short dport, unsigned long ack)
 {
-	struct list    *ret;
+	struct list *ret;
 
-	ret = get_packet(l, dport);
-	if (ret != NULL) {
+	ret = get_packet (l, dport);
+	if (ret != NULL)
+        {
 #ifdef SHOW_RETRIES
-		printf("RETRIES FOR %d = %d\n", dport, ret->retries);
+		printf ("RETRIES FOR %d = %d\n", dport, ret->retries);
 #endif
 		ret->retries++;
 		ret->when = ack;
 		return l;
 	}
-	ret = emalloc(sizeof(struct list));
-
+	ret = emalloc (sizeof (struct list));
 
 	ret->next = l;
 	ret->prev = NULL;
@@ -263,16 +285,16 @@ add_packet(struct list * l, unsigned short dport, unsigned long ack)
 }
 
 
-
-struct list    *
-rm_packet(struct list * l, unsigned short dport)
+struct list*
+rm_packet (struct list * l, unsigned short dport)
 {
-	struct list    *ret = l;
-	struct list    *p = get_packet(l, dport);
+	struct list *ret = l;
+	struct list *p = get_packet (l, dport);
 
-	if (p == NULL) {
+	if (p == NULL)
+	{
 #if DEBUG > 1
-		fprintf(stderr, "Odd - no entry for %d - RTT too low ?!\n", dport);
+		fprintf (stderr, "Odd - no entry for %d - RTT too low ?!\n", dport);
 #endif
 		return l;
 	}
@@ -288,8 +310,8 @@ rm_packet(struct list * l, unsigned short dport)
 	return ret;
 }
 
-struct list    *
-rm_dead_packets(struct list * l, unsigned long rtt, int *retry)
+struct list*
+rm_dead_packets (struct list * l, unsigned long rtt, int *retry)
 {
 	struct list    *ret = l;
 	struct list    *p = l;
@@ -325,32 +347,34 @@ rm_dead_packets(struct list * l, unsigned long rtt, int *retry)
 
 
 
-
 /*-----------------------------------------------------------------------------*/
 
 
-struct tcphdr * extracttcp(char * pkt, int len)
+struct tcphdr *
+extracttcp (char * pkt, int len)
 {
  struct ip * ip;
         struct tcphdr  *tcp;
- 
+
  ip = (struct ip*)pkt;
- if(ip->ip_hl * 4 + sizeof(struct tcphdr) > len)
+ if(ip->ip_hl * 4 + sizeof (struct tcphdr) > len)
   return NULL;
-  
+
  tcp = (struct tcphdr*)(pkt + ip->ip_hl * 4);
  return tcp;
 }
 
-struct tcphdr * v6_extracttcp(char * pkt, int len)
+struct tcphdr *
+v6_extracttcp (char * pkt, int len)
 {
   struct tcphdr  *tcp;
   tcp = (struct tcphdr*)(pkt + 40);
   return tcp;
 }
 
-unsigned long 
-extractack(char *pkt, int len, int family)
+
+unsigned long
+extractack (char *pkt, int len, int family)
 {
  unsigned long   ret;
  struct tcphdr *tcp;
@@ -367,8 +391,8 @@ extractack(char *pkt, int len, int family)
 }
 
 
-unsigned short 
-extractsport(char *pkt, int len, int family)
+unsigned short
+extractsport (char *pkt, int len, int family)
 {
   struct tcphdr *tcp;
 
@@ -378,29 +402,31 @@ extractsport(char *pkt, int len, int family)
         tcp = v6_extracttcp(pkt, len);
 
  if(tcp == NULL)return 0;
- 
+
 	return ntohs(tcp->th_sport);
 }
 
-int 
-issynack(char *pkt, int len, int family)
+int
+issynack (char *pkt, int len, int family)
 {
   struct tcphdr *tcp;
 
-  if(family == AF_INET)
-	tcp = extracttcp(pkt, len); 
+  if (family == AF_INET)
+	tcp = extracttcp(pkt, len);
   else
         tcp = v6_extracttcp(pkt, len);
  
- if(tcp == NULL)return 0;
+  if (tcp == NULL)
+    return 0;
 
-	return tcp->th_flags == (TH_SYN | TH_ACK);
+  return tcp->th_flags == (TH_SYN | TH_ACK);
 }
 
-char           *
-mktcp(struct in_addr src, int sport, struct in_addr dst, int dport, unsigned long th_ack, unsigned char flag)
+char*
+mktcp (struct in_addr src, int sport, struct in_addr dst, int dport,
+       unsigned long th_ack, unsigned char flag)
 {
-	static char     pkt[sizeof(struct ip) + sizeof(struct tcphdr)];
+	static char     pkt[sizeof (struct ip) + sizeof (struct tcphdr)];
 	struct ip      *ip;
 	struct tcphdr  *tcp;
 	struct pseudohdr pseudohdr;
@@ -410,7 +436,7 @@ mktcp(struct in_addr src, int sport, struct in_addr dst, int dport, unsigned lon
 	ip->ip_hl = 5;
 	ip->ip_v = 4;
 	ip->ip_tos = 0;
-	ip->ip_len = FIX(sizeof(struct ip) + sizeof(struct tcphdr));
+	ip->ip_len = FIX (sizeof (struct ip) + sizeof (struct tcphdr));
 	ip->ip_id = rand();
 	ip->ip_off = 0;
 	ip->ip_ttl = 64;
@@ -418,9 +444,9 @@ mktcp(struct in_addr src, int sport, struct in_addr dst, int dport, unsigned lon
 	ip->ip_sum = 0;
 	ip->ip_src.s_addr = src.s_addr;
 	ip->ip_dst.s_addr = dst.s_addr;
-	ip->ip_sum = in_cksum((u_short *) pkt, sizeof(struct ip));
+	ip->ip_sum = in_cksum ((u_short *) pkt, sizeof (struct ip));
 
-	tcp = (struct tcphdr *) (&(pkt[sizeof(struct ip)]));
+	tcp = (struct tcphdr *) (&(pkt[sizeof (struct ip)]));
 	tcp->th_sport = htons(sport);
 	tcp->th_dport = htons(dport);
 	tcp->th_seq = th_ack;
@@ -436,18 +462,19 @@ mktcp(struct in_addr src, int sport, struct in_addr dst, int dport, unsigned lon
 	pseudohdr.saddr.s_addr = src.s_addr;
 	pseudohdr.daddr.s_addr = dst.s_addr;
 	pseudohdr.protocol = IPPROTO_TCP;
-	pseudohdr.length = htons(sizeof(struct tcphdr));
-	bcopy((char *) tcp, (char *) &pseudohdr.tcpheader, sizeof(struct tcphdr));
-	bcopy(&pseudohdr, tcpsumdata, sizeof(struct pseudohdr));
-	tcp->th_sum = in_cksum((unsigned short *) tcpsumdata, 12 + sizeof(struct tcphdr));
+	pseudohdr.length = htons(sizeof (struct tcphdr));
+	bcopy((char *) tcp, (char *) &pseudohdr.tcpheader, sizeof (struct tcphdr));
+	bcopy(&pseudohdr, tcpsumdata, sizeof (struct pseudohdr));
+	tcp->th_sum = in_cksum((unsigned short *) tcpsumdata, 12 + sizeof (struct tcphdr));
 
 	return pkt;
 }
 
 char *
-mktcpv6(struct in6_addr *src, int sport, struct in6_addr *dst, int dport, unsigned long th_ack, unsigned char flag)
+mktcpv6 (struct in6_addr *src, int sport, struct in6_addr *dst, int dport,
+         unsigned long th_ack, unsigned char flag)
 {
-  static char pkt[sizeof(struct tcphdr)];
+  static char pkt[sizeof (struct tcphdr)];
   struct tcphdr  *tcp;
 
   tcp = (struct tcphdr *) (&(pkt[0]));
@@ -465,8 +492,8 @@ mktcpv6(struct in6_addr *src, int sport, struct in6_addr *dst, int dport, unsign
 }
 /*--------------------------------------------------------------------*/
 
-int 
-find_rtt(struct in_addr dst, unsigned long *rtt)
+int
+find_rtt (struct in_addr dst, unsigned long *rtt)
 {
 	int             soc;
 	unsigned short  ports[] = {21, 22, 34, 25, 53, 79, 80, 110, 113, 135, 139, 143, 264, 389, 443, 993, 1454, 1723, 3389, 8080, 0};
@@ -497,7 +524,7 @@ find_rtt(struct in_addr dst, unsigned long *rtt)
 		return -1;
 	}
 	skip = get_datalink_size(bpf_datalink(bpf));
-	bzero(&soca, sizeof(soca));
+	bzero(&soca, sizeof (soca));
 	soca.sin_family = AF_INET;
 	soca.sin_addr = dst;
 
@@ -513,7 +540,7 @@ find_rtt(struct in_addr dst, unsigned long *rtt)
 		printf("send to port %d\n", ports[i]);
 #endif
 
-		e = sendto(soc, pkt, sizeof(struct ip) + sizeof(struct tcphdr), 0, (struct sockaddr *) & soca, sizeof(soca));
+		e = sendto(soc, pkt, sizeof (struct ip) + sizeof (struct tcphdr), 0, (struct sockaddr *) & soca, sizeof (soca));
 		if (e < 0) {
 			perror("sendto ");
 			close(soc);
@@ -551,7 +578,7 @@ find_rtt(struct in_addr dst, unsigned long *rtt)
 
 
 		pkt = mktcp(src, magic, dst, use[n % num], ack, TH_SYN);
-		e = sendto(soc, pkt, sizeof(struct ip) + sizeof(struct tcphdr), 0, (struct sockaddr *) & soca, sizeof(soca));
+		e = sendto(soc, pkt, sizeof (struct ip) + sizeof (struct tcphdr), 0, (struct sockaddr *) & soca, sizeof (soca));
 		if (e < 0)
 			perror("sendto ");
 		res = (char *) bpf_next_tv(bpf, &len, &tv);
@@ -589,32 +616,38 @@ find_rtt(struct in_addr dst, unsigned long *rtt)
 
 	close(soc);
 	bpf_close(bpf);
-        if(max == 0)max = htonl(1 << 28);
+        if(max == 0) max = htonl(1 << 28);
 	*rtt = max;
 	return 1;
 }
 
-
-struct list    *
-sendpacket(int soc, int bpf, int skip, struct in_addr dst, struct in_addr src, int dport, int magic, struct list * packets, unsigned long * rtt, int sniff, struct arglist * env)
+/**
+ * @param sniff If != 0, "sniff" (listen to incoming packages), else just
+ *              add packet.
+ */
+struct list*
+sendpacket (int soc, int bpf, int skip, struct in_addr dst, struct in_addr src,
+            int dport, int magic, struct list * packets, unsigned long * rtt,
+            int sniff, struct arglist * env)
 {
 	unsigned long   ack = maketime();
-	char           *pkt = mktcp(src, magic, dst, dport, ack, TH_SYN);
+	char           *pkt = mktcp (src, magic, dst, dport, ack, TH_SYN);
 	int             len;
 	char           *res;
 	struct sockaddr_in soca;
-  	struct timeval rtt_tv = timeval(*rtt);
+	struct timeval rtt_tv = timeval(*rtt);
 	int family = AF_INET;
 
-	bzero(&soca, sizeof(soca));
-	soca.sin_family = AF_INET;
-	soca.sin_addr = dst;
+        bzero (&soca, sizeof (soca));
+        soca.sin_family = AF_INET;
+        soca.sin_addr = dst;
+
 	rtt_tv.tv_sec *= 1000;
 	rtt_tv.tv_sec /= 8;
 	
 	rtt_tv.tv_usec += (rtt_tv.tv_sec % 1000) * 1000;
 	rtt_tv.tv_sec  /= 1000;
-        if ( rtt_tv.tv_sec >= 1 )
+        if (rtt_tv.tv_sec >= 1)
 		{
 		rtt_tv.tv_sec  = 1;
 		rtt_tv.tv_usec = 0;
@@ -633,7 +666,7 @@ sendpacket(int soc, int bpf, int skip, struct in_addr dst, struct in_addr src, i
 	}
 	if (sniff != 0) {
 again:
-		res = (char *) bpf_next_tv(bpf, &len, &rtt_tv);
+		res = (char *) bpf_next_tv (bpf, &len, &rtt_tv);
 		if (res != NULL) {
 			unsigned short  sport = extractsport(res + skip, len, family);
 			int             synack = issynack(res + skip, len, family);
@@ -641,17 +674,17 @@ again:
 			if (synack) {
 			  char * rst;
 #ifdef DEBUG
-				printf("=> Port %d is open\n", sport);
+                          printf("=> Port %d is open\n", sport);
 #endif
-		  	   scanner_add_port(env, sport, "tcp");
+			   scanner_add_port (env, sport, "tcp");
 			  /* Send a RST to make sure the connection is closed on the remote side */
 			  rst = mktcp(src, magic, dst, sport, ack + 1, TH_RST);
 			  sendto(soc, rst, sizeof(struct ip) + sizeof(struct tcphdr), 0, (struct sockaddr *) & soca, sizeof(soca));
-			
+
 			  /* Adjust the rtt */
 			  *rtt = compute_rtt(rack);
-			  if ( ntohl(*rtt) >= ( 1 << 28 ) ) *rtt = 1 << 28;
-
+			  if (ntohl (*rtt) >= (1 << 28))
+			    *rtt = 1 << 28;
 			}
 			packets = rm_packet(packets, sport);
 			rtt_tv.tv_sec = 0;
@@ -663,7 +696,10 @@ again:
 }
 
 struct list *
-v6_sendpacket(int soc, int bpf, int skip, struct in6_addr *dst, struct in6_addr *src, int dport, int magic, struct list * packets, unsigned long * rtt, int sniff, struct arglist * env)
+v6_sendpacket (int soc, int bpf, int skip, struct in6_addr *dst,
+               struct in6_addr *src, int dport, int magic,
+               struct list * packets, unsigned long * rtt, int sniff,
+               struct arglist * env)
 {
   unsigned long ack = maketime();
   char *pkt = mktcpv6(src, magic, dst, dport, ack, TH_SYN);
@@ -720,8 +756,12 @@ v6_sendpacket(int soc, int bpf, int skip, struct in6_addr *dst, struct in6_addr
 }
 
 
-int 
-scan(struct arglist * env, struct in6_addr *dst6, unsigned long rtt)
+/**
+ * @return -1 if the socket could not be opened (error), 0 otherwise.
+ */
+int
+scan (struct arglist * env, char* hostname, char* portrange,
+      struct in6_addr *dst6, unsigned long rtt)
 {
   int             num;
   int             soc;
@@ -733,103 +773,122 @@ scan(struct arglist * env, struct in6_addr *dst6, unsigned long rtt)
   int             skip;
   int             i;
   struct list    *packets = NULL;
-  struct arglist *globals = arg_get_value(env, "globals");
-  struct arglist *hostinfos = arg_get_value(env, "HOSTNAME");
-  char           *hname = arg_get_value(hostinfos, "NAME");
+  struct arglist *globals = (env) ? arg_get_value (env, "globals") : NULL;
   int             retry;
-  char           *range = get_preference(env, "port_range");
   unsigned short *ports;
   int family;
 
   dst.s_addr = 0;
 
-  if(IN6_IS_ADDR_V4MAPPED(dst6))
-  {
-    family = AF_INET;
-    dst.s_addr = dst6->s6_addr32[3];
-    soc = rawsocket(AF_INET);
-  }
+  if (IN6_IS_ADDR_V4MAPPED (dst6))
+    {
+      family = AF_INET;
+      dst.s_addr = dst6->s6_addr32[3];
+      soc = rawsocket (AF_INET);
+    }
   else
-  {
-    family = AF_INET6;
-    soc = rawsocket(AF_INET6);
-  }
+    {
+      family = AF_INET6;
+      soc = rawsocket (AF_INET6);
+    }
 #ifdef DEBUG
-  printf("===> port range = %s\n", range);
+  printf ("===> Port range = %s\n", portrange);
+  printf ("===> Target IP Family = %s\n", (family == AF_INET6) ? "v6"
+                                                               : "v4");
+  printf ("===> Target = %s\n", inet_ntoa (dst));
 #endif
 
-  ports = (unsigned short *) getpts(range, &num);
+  ports = (unsigned short *) getpts (portrange, &num);
 
   if (soc < 0)
-  {
-    printf("error opeining raw socket\n");
-    return -1;
-  }
-
-  if(family == AF_INET)
-    bpf = openbpf(dst, &src, magic);
-  else
-    bpf = v6_openbpf(dst6, &src6, magic);
-  skip = get_datalink_size(bpf_datalink(bpf));
-
-  for (i = 0; i < num ; i += 2) {
-    if (i % 100 == 0)
-      comm_send_status(globals, hname, "portscan", i, num);
-
-    if(family == AF_INET)
-      packets = sendpacket(soc, bpf, skip, dst, src, ports[i], magic, packets, &rtt, 0, env);
-    else
-      packets = v6_sendpacket(soc, bpf, skip, dst6, &src6, ports[i], magic, packets, &rtt, 0, env);
-    if ( i + 1 < num )
     {
-      if(family == AF_INET)
-        packets = sendpacket(soc, bpf, skip, dst, src, ports[i + 1], magic, packets, &rtt, 1, env);
+      printf ("error opening raw socket\n");
+      return -1;
+    }
+
+  if (family == AF_INET)
+    bpf = openbpf (dst, &src, magic);
+  else
+    bpf = v6_openbpf (dst6, &src6, magic);
+  skip = get_datalink_size (bpf_datalink (bpf));
+
+  /** This will send packets to ports not in ports list, will it? */
+  for (i = 0; i < num ; i += 2)
+    {
+#ifdef DEBUG
+      printf ("====> Sending packet to (at least) %d\n", ports[i]);
+#endif
+      if (i % 100 == 0)
+        comm_send_status (globals, hostname, "portscan", i, num);
+
+      if (family == AF_INET)
+        packets = sendpacket (soc, bpf, skip, dst, src, ports[i], magic,
+                              packets, &rtt, 0, env);
       else
-        packets = v6_sendpacket(soc, bpf, skip, dst6, &src6, ports[i + 1], magic, packets, &rtt, 1, env);
+        packets = v6_sendpacket (soc, bpf, skip, dst6, &src6, ports[i], magic,
+                                 packets, &rtt, 0, env);
+      if (i + 1 < num)
+        {
+#ifdef DEBUG
+          printf ("=====>> Sniffing %d\n", ports[i+1]);
+#endif
+          if (family == AF_INET)
+            packets = sendpacket (soc, bpf, skip, dst, src, ports[i + 1],
+                                  magic, packets, &rtt, 1, env);
+          else
+            packets = v6_sendpacket (soc, bpf, skip, dst6, &src6, ports[i + 1],
+                                     magic, packets, &rtt, 1, env);
+        }
     }
-  }
 
 #ifdef DEBUG
-  printf("Done with the sending\n");
+  printf ("Done with the sending\n");
 #endif
 
-  /* How to do this for ipv6. This causes much scan delay for IPv6*/
-  if(family == AF_INET)
+  /** @TODO How to do this for ipv6? This causes much scan delay for IPv6. */
+  if (family == AF_INET)
   {
-    while (packets != NULL) {
-      i = 0;
-      retry = 0;
-      packets = rm_dead_packets(packets, rtt, &retry);
-      while (retry != 0 && i < 2) {
-        packets = sendpacket(soc, bpf, skip, dst, src, retry, magic, packets, &rtt, 0, env);
-        packets = rm_dead_packets(packets, rtt, &retry);
-        i++;
+    while (packets != NULL)
+      {
+#ifdef DEBUG
+        printf ("===> Retry...\n");
+#endif
+        i = 0;
+        retry = 0;
+        packets = rm_dead_packets (packets, rtt, &retry);
+        while (retry != 0 && i < 2)
+          {
+            packets = sendpacket (soc, bpf, skip, dst, src, retry, magic,
+                                  packets, &rtt, 0, env);
+            packets = rm_dead_packets (packets, rtt, &retry);
+            i++;
+          }
+        packets = sendpacket (soc, bpf, skip, dst, src, retry, magic, packets,
+                              &rtt, 1, env);
       }
-      packets = sendpacket(soc, bpf, skip, dst, src, retry, magic, packets, &rtt, 1, env);
-    }
   }
 
-  comm_send_status(globals, hname, "portscan", num, num);
+  comm_send_status (globals, hostname, "portscan", num, num);
 #if 0
-  plug_set_key(env, "Host/num_ports_scanned", ARG_INT, (void*)num);
+  plug_set_key (env, "Host/num_ports_scanned", ARG_INT, (void*)num);
 #endif
-  close(soc);
-  bpf_close(bpf);
-  if(ports != NULL)efree(&ports);
+  close (soc);
+  bpf_close (bpf);
+  if (ports != NULL)
+    efree (&ports);
   if (num >= 65535)
-    plug_set_key(env, "Host/full_scan", ARG_INT, (void*) 1);
+    plug_set_key (env, "Host/full_scan", ARG_INT, (void*) 1);
+
   return 0;
 }
 
 
-
-
 #define EN_NAME "SYN Scan"
 #define EN_DESC "\n\
 This plugins performs a supposedly fast SYN port scan\n\
 It does so by computing the RTT (round trip time) of the packets\n\
 coming back and forth between the openvassd host and the target,\n\
-then it uses that to quicky send SYN packets to the remote host\n"
+then it uses that to quickly send SYN packets to the remote host.\n"
 
 
 #define COPYRIGHT "Copyright (C) Renaud Deraison <deraison@cvs.nessus.org>"
@@ -838,40 +897,38 @@ then it uses that to quicky send SYN packets to the remote host\n"
 #define EN_FAMILY "Port scanners"
 
 int
-plugin_init(struct arglist * desc)
+plugin_init (struct arglist * desc)
 {
-	plug_set_id(desc, 11219);
-	plug_set_version(desc, "$Revision: 1266 $");
+  plug_set_id (desc, 11219);
+  plug_set_version (desc, "$Revision: 6488 $");
 
+  plug_set_name (desc, EN_NAME);
+  plug_set_summary (desc, EN_SUMMARY);
+  plug_set_description (desc, EN_DESC);
 
+  plug_set_copyright (desc, COPYRIGHT);
+  plug_set_category (desc, ACT_SCANNER);
+  plug_set_family (desc, EN_FAMILY);
 
-	plug_set_name(desc, EN_NAME);
-	plug_set_summary(desc, EN_SUMMARY);
-	plug_set_description(desc, EN_DESC);
-
-	plug_set_copyright(desc, COPYRIGHT);
-	plug_set_category(desc, ACT_SCANNER);
-	plug_set_family(desc, EN_FAMILY);
-
-	plug_set_dep(desc, "ping_host.nasl");
-	return (0);
+  plug_set_dep (desc, "ping_host.nasl");
+  return (0);
 }
 
 
-
 int
-plugin_run(struct arglist * env)
+plugin_run (struct arglist * env)
 {
-	unsigned long   rtt;
-  struct in6_addr *dst6 = plug_get_host_ip(env);
-  struct in_addr *dst;
-  struct in_addr inaddr;
-	struct timeval  tv;
+  unsigned long   rtt;
+  struct in6_addr *dst6 = plug_get_host_ip (env);
+  struct in_addr  *dst;
+  struct in_addr  inaddr;
+  struct timeval  tv;
 
   inaddr.s_addr = dst6->s6_addr32[3];
   dst = &inaddr;
 
-      if ( islocalhost(dst) ) return 0;
+  if (islocalhost (dst))
+    return 0;
 
 #if 0
 	if (find_rtt(*dst, &rtt) < 0) {
@@ -879,23 +936,65 @@ plugin_run(struct arglist * env)
 		return (1);
 	}
 #endif
-	rtt = htonl(1 << 28);
+    rtt = htonl (1 << 28);
 
 #ifdef DEBUG
-	printf("RTT = 0x%.8x\n", ntohl(rtt));
+    printf ("RTT = 0x%.8x\n", ntohl (rtt));
 #endif
 
-	tv = timeval(rtt);
-	
+  /** @TODO belongs to debug section? */
+  tv = timeval (rtt);
+
 #ifdef DEBUG
-	printf("That's %d seconds and %d usecs\n", tv.tv_sec, tv.tv_usec);
+	printf ("That's %d seconds and %d usecs\n", tv.tv_sec, tv.tv_usec);
 #endif
 
-	scan(env, dst6, rtt);
-	plug_set_key(env, "Host/scanned", ARG_INT, (void *) 1);
-	plug_set_key(env, "Host/scanners/synscan", ARG_INT, (void*)1);
-	return 0;
+  struct arglist *hostinfos = arg_get_value (env, "HOSTNAME");
+  char           *hostname  = arg_get_value (hostinfos, "NAME");
+  char           *range = get_preference (env, "port_range");
+  scan (env, hostname, range, dst6, rtt);
+  plug_set_key (env, "Host/scanned", ARG_INT, (void *) 1);
+  plug_set_key (env, "Host/scanners/synscan", ARG_INT, (void*)1);
+  return 0;
 }
 
 
+#ifdef STANDALONE
+/**
+ * @brief main- function of a basic standalone syn-scanner (for debugging
+ * @brief purposes). Define STANDALONE and DEBUG and link against
+ * @brief libopenvas_hg, libopenvas_base and libopenvas_misc.
+ *
+ * Call like standalone-synscan \<host\> [portrange]
+ * (e.g. "standalone-syncscan myhost.mydomain 10-100")
+ */
+int
+main (int argc, char* argv[])
+{
+  char* target    = NULL;
+  char* portrange = "default";
+  unsigned long rtt = htonl (1 << 28);
+  struct in6_addr dst6;
 
+  if (argc < 2)
+    {
+      printf ("Usage: synscan_standalone <host> [portrange].\n");
+      exit (1);
+    }
+
+  if (argc == 3)
+    {
+      portrange = argv[2];
+    }
+
+  target = argv[1];
+
+  printf ("Resolving host...\n");
+  hg_resolv (target, &dst6, AF_INET6);
+  printf ("Starting scan\n");
+  scan (NULL, target, portrange, &dst6, rtt);
+  printf ("Done.\n");
+
+  exit (0);
+}
+#endif
