@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: save_kb.c 5364 2009-10-05 09:19:22Z felix $
+* $Id: save_kb.c 6952 2010-03-12 11:39:29Z jan $
 * Description: Saves the currently used knowledge base.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -52,7 +52,6 @@
 #include "comm.h"
 #include "users.h"
 #include "locks.h"
-#ifdef ENABLE_SAVE_KB
 
 #ifndef MAP_FAILED
 #define MAP_FAILED (void*)(-1)
@@ -882,5 +881,3 @@ diff_scan_enable (struct arglist * pluginargs)
 {
  arg_add_value(pluginargs, "DIFF_SCAN", ARG_INT, sizeof(int), (void*)1);
 }
-
-#endif /* ENABLE_SAVE_KB */
